@@ -10,9 +10,16 @@ from twisted.trial.unittest import TestCase
 from twisted.python.usage import UsageError
 from twisted.mail import protocols
 from twisted.mail.tap import Options, makeService
-from twisted.python import deprecate, versions
 from twisted.python.filepath import FilePath
 from twisted.internet import endpoints, defer
+from twisted.python import util
+
+try:
+    import OpenSSL
+except ImportError, e:
+    sslSkip = str(e)
+else:
+    sslSkip = None
 
 
 class OptionsTestCase(TestCase):
@@ -47,22 +54,6 @@ class OptionsTestCase(TestCase):
             '--aliases', self.aliasFilename])
 
 
-    def testPasswordfileDeprecation(self):
-        """
-        Test that the --passwordfile option will emit a correct warning.
-        """
-        passwd = FilePath(self.mktemp())
-        passwd.setContent("")
-        options = Options()
-        options.opt_passwordfile(passwd.path)
-        warnings = self.flushWarnings([self.testPasswordfileDeprecation])
-        self.assertEqual(warnings[0]['category'], DeprecationWarning)
-        self.assertEqual(len(warnings), 1)
-        msg = deprecate.getDeprecationWarningString(options.opt_passwordfile,
-                             versions.Version('twisted.mail', 11, 0, 0))
-        self.assertEqual(warnings[0]['message'], msg)
-
-
     def test_barePort(self):
         """
         A bare port passed to I{--pop3} results in deprecation warning in
@@ -157,8 +148,7 @@ class OptionsTestCase(TestCase):
         The deprecated I{--pop3s} and I{--certificate} options set up a POP3 SSL
         server.
         """
-        cert = FilePath(self.mktemp())
-        cert.setContent("")
+        cert = FilePath(__file__).sibling("server.pem")
         options = Options()
         options.parseOptions(['--pop3s', '8995',
                               '--certificate', cert.path])
@@ -175,6 +165,8 @@ class OptionsTestCase(TestCase):
             warnings[0]['message'],
             "Specifying plain ports and/or a certificate is deprecated since "
             "Twisted 11.0; use endpoint descriptions instead.")
+    if sslSkip is not None:
+        test_pop3sBackwardCompatibility.skip = sslSkip
 
 
     def test_esmtpWithoutHostname(self):
